Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRemoteOriginURL ¶
func ParseRepoFolder ¶
Types ¶
type GitRepo ¶
type GitRepo struct {
// contains filtered or unexported fields
}
GitRepo is the basic store object.
func New ¶
New returns a new GPGStore. The `repo` is the supplied git repository. Optionally you can include a string for which folder to save the repo to. The default location is the current directory.
func (*GitRepo) AddData ¶
AddData will write the `data` to a new file, `fp` in the repo and then perform a commit with the message of that files name. Note that the filename should be respective to the root of the repository.
Click to show internal directories.
Click to hide internal directories.